==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/core/kmfnethost.h <==
//
// C++ Interface: kmfnethost
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@gmail.com>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFNETHOST_H
#define KMFNETHOST_H

#include "netfilterobject.h"

// QT includes
#include <qptrlist.h>
#include <qguardedptr.h>
#include <qstring.h>
#include <qdom.h>

// KDE includes
#include <kdemacros.h>

// Project includes

class KMFGenericDoc;
class KMFProtocol;
class KMFError;
class KMFCheckInput;
class KMFNetZone;
class IPAddress;
/**
@author Christian Hubinger
*/
class KDE_EXPORT KMFNetHost : public NetfilterObject {
public:
	KMFNetHost( QObject *parent, const QString& name );
	~KMFNetHost();

	KMFNetZone* zone() const {
		return m_zone;
	}


	const QString& guiName() const {
		return m_guiName;
	};
	void setGuiName( const QString& );

	IPAddress* address() const {
		return m_address;
	};
	
	void setAddress( const QString& );

	void setMaskLength( int );
	
	void setParentZone( KMFNetZone* );
	
	bool logIncoming() {
		return m_logIncoming;
	}
	void setLogIncoming( bool );

	bool logOutgoing() {
		return m_logOutgoing;
	}
	void setLogOutgoing( bool );

	void setLimit( int num, const QString& scale );
	
	bool limit() const;
	int limitRate() const;
	const QString& limitScale() const;
	
	const QDomDocument& getDOMTree();
	void loadXML(const QDomDocument& );

	KMFProtocol* addProtocol( const QString& name, const QDomDocument& xml );
	KMFProtocol* addProtocol( const QString& name );
	void delProtocol( KMFProtocol* );
	bool protocolInherited( const QString& ) const;
	KMFProtocol* findProtocol( const QString& name ) const;
	QPtrList<KMFProtocol>& protocols() const;

private: // Data
	QGuardedPtr<KMFNetZone> m_zone;
	IPAddress *m_address;
// 	int m_maskLen;
	QPtrList<KMFProtocol> m_protocols;
	QString m_guiName;
	bool m_logIncoming, m_logOutgoing;
	QString m_limitScale;
	int m_limitNum;
};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/core/kmfnethost.h <==
//
// C++ Interface: kmfnethost
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFNETHOST_H
#define KMFNETHOST_H

#include "kmftarget.h"
#include "netfilterobject.h"


// QT includes
#include <qptrlist.h>
#include <qguardedptr.h>
#include <qstring.h>
#include <qdom.h>
#include <quuid.h>

// KDE includes
#include <kdemacros.h>


// Project includes

namespace KMF {
class KMFGenericDoc;
class KMFProtocol;
class KMFProtocolUsage;
class KMFError;
class KMFCheckInput;
class KMFNetZone;
class IPAddress;
class KMFNetwork;

/**
@author Christian Hubinger
*/

class KDE_EXPORT KMFNetHost : public KMFTarget {
	Q_OBJECT
public:
	KMFNetHost( NetfilterObject *parent, const char* name, const QString& Hostname, KMFNetwork* net );
	virtual ~KMFNetHost();

	virtual int type();
	virtual void clear();
	
	bool logIncoming() {
		return m_logIncoming;
	}
	void setLogIncoming( bool );

	bool logOutgoing() {
		return m_logOutgoing;
	}
	void setLogOutgoing( bool );

	void setLimit( int num, const QString& scale );
	
	bool limit() const;
	int limitRate() const;
	const QString& limitScale() const;
	
	virtual const QDomDocument& getDOMTree();
	virtual void loadXML(const QDomDocument&, QStringList& errors );
	virtual void loadXML( QDomNode, QStringList& errors );
	
	KMFProtocolUsage* addProtocolUsage( const QUuid& protocolUuid, const QDomDocument& xml );
	
	void delProtocolUsage( KMFProtocolUsage*, bool destructive = true );
	bool protocolInherited( const QUuid& uuid ) const;
	KMFProtocolUsage* findProtocolUsageByProtocolUuid( const QUuid& uuid ) const;
	
	QPtrList<KMFProtocolUsage>& protocols() const;

protected slots:
	void slotOnProtocolUsageDeleted( QObject* protocol );
	
private: // Data
// 	int m_maskLen;
	QPtrList<KMFProtocolUsage> m_protocols;
	bool m_logIncoming, m_logOutgoing;
	QString m_limitScale;
	int m_limitNum;
};
}
#endif
